#ifndef THREAD_ARTICLE_H
#define THREAD_ARTICLE_H

#include <pan/base/article.h>

enum {
	THREAD_NOTHING,
	THREAD_WATCHED,
	THREAD_IGNORED
};

void thread_set_state (const Article *, int state);

int thread_get_state (const Article *);

void thread_shutdown_module (void);

#endif
